@@ -1,11 +1,11 @@
 # ABSTRACT: TestRail testing harness
 # PODNAME: Test::Rail::Harness
 package Test::Rail::Harness;
-$Test::Rail::Harness::VERSION = '0.015';
+$Test::Rail::Harness::VERSION = '0.016';
 use strict;
 use warnings;
 
-use base qw/TAP::Harness/;
+use parent qw/TAP::Harness/;
 
 # inject parser_class as Test::Rail::Parser.
 sub new {
@@ -67,7 +67,7 @@ Test::Rail::Harness - TestRail testing harness
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 DESCRIPTION
 
